#include <libint2.h>
#ifdef __cplusplus
extern "C" {
#endif
void OSVRRP0InBra_aB_p__0__pf__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2);
#ifdef __cplusplus
};
#endif
